@@ -76,7 +76,7 @@ def update_db():
         cursor.execute(command)
         version = cursor.fetchone()[0]
         if DIST_FLAG == 1:
-            resource = json.loads(pkg_resources.read_text("static", "db_settings.txt"))
+            resource = json.loads(pkg_resources.read_text("dpl_geodb/static", "db_settings.txt"))
         else: 
             with open("/Users/alex/Documents/work/database_package/datclass/static/db_settings.txt") as static:
                 resource = json.load(static)
